Enum Rlpsn
#[repr(u8)]pub enum Rlpsn {
LowPower = 0,
Normal = 1,
}Variants
LowPower = 0
RAM enters to low power mode when system enters to STOP.
Normal = 1
RAM remains in normal mode when system enters to STOP.
Implementations